@@ -7,7 +7,7 @@ from click.testing import CliRunner
 def cli_runner(request):
     """Instance of `click.testing.CliRunner`. Can be configured with `@pytest.mark.runner_setup`.
 
-    @pytest.mark.runner_setup(charset='cp1251')
+    @pytest.mark.runner_setup(charset="cp1251")
     def test_something(cli_runner):
         ...
     """
